Greenhouse gases are gases such as Carbon Dioxide (CO2) and Methane (CH4) that absorb and re-emit infrared radiation. In the atmosphere, their interaction with infrared radiation ultimately leads to a warming of the atmosphere and surface.

Atmospheric concentrations of greenhouse gases reflect a balance between emissions from human activities (such as the burning of fossil fuels), natural sources, and sinks in the biosphere and ocean. Increasing levels of greenhouse gases in the atmosphere due to human activities have been the major driver of climate change since the mid-twentieth century. Global average mole fractions of greenhouse gases (as shown in the figures) are calculated from in situ observations made at multiple sites in the Global Atmosphere Watch (GAW) Programme of WMO and partner networks.

The ocean is a sink for CO2. Some of the excess CO2 in the atmosphere is absorbed by the ocean. CO2 reacts with seawater and lowers its pH. This process is known as ocean acidification.

## What the IPCC says

A 1.1 Observed increases in well-mixed greenhouse gas (GHG) concentrations since around 1750 are unequivocally caused by human activities. Since 2011 (measurements reported in AR5), concentrations have continued to increase in the atmosphere, reaching annual averages of 410 parts per million (ppm) for carbon dioxide (CO2), 1866 parts per billion (ppb) for methane (CH4), and 332 ppb for nitrous oxide (N2O) in 2019. Land and ocean have taken up a near-constant proportion (globally about 56% per year) of CO2 emissions from human activities over the past six decades, with regional differences (high confidence).